@@ -3,6 +3,7 @@ use git_cliff_core::config::{
 	ChangelogConfig,
 	CommitParser,
 	GitConfig,
+	LinkParser,
 };
 use git_cliff_core::error::Result;
 use git_cliff_core::release::*;
@@ -15,21 +16,30 @@ use std::fmt::Write;
 fn generate_changelog() -> Result<()> {
 	let changelog_config = ChangelogConfig {
 		header: Some(String::from("this is a changelog")),
-		body:   String::from(
+		body:   Some(String::from(
 			r#"
-        ## Release {{ version }}
-        {% for group, commits in commits | group_by(attribute="group") %}
-        ### {{ group }}
-        {% for commit in commits %}
-        - {{ commit.message }}{% endfor %}
-        {% endfor %}"#,
-		),
+## Release {{ version }}
+{% for group, commits in commits | group_by(attribute="group") %}
+### {{ group }}
+{% for commit in commits %}
+{%- if commit.scope -%}
+- *({{commit.scope}})* {{ commit.message }}{%- if commit.links %} ({% for link in commit.links %}[{{link.text}}]({{link.href}}) {% endfor -%}){% endif %}
+{% else -%}
+- {{ commit.message }}
+{% endif -%}
+{% if commit.breaking -%}
+{% raw %}  {% endraw %}- **BREAKING**: {{commit.breaking_description}}
+{% endif -%}
+{% endfor -%}
+{% endfor %}"#,
+		)),
 		footer: Some(String::from("eoc - end of changelog")),
 		trim:   None,
 	};
 	let git_config = GitConfig {
-		conventional_commits: true,
-		commit_parsers:       Some(vec![
+		conventional_commits:  Some(true),
+		filter_unconventional: Some(true),
+		commit_parsers:        Some(vec![
 			CommitParser {
 				message:       Regex::new("^feat").ok(),
 				body:          None,
@@ -45,18 +55,47 @@ fn generate_changelog() -> Result<()> {
 				skip:          None,
 			},
 		]),
-		filter_commits:       Some(true),
-		tag_pattern:          None,
-		skip_tags:            None,
+		filter_commits:        Some(true),
+		tag_pattern:           None,
+		skip_tags:             None,
+		ignore_tags:           None,
+		date_order:            None,
+		sort_commits:          None,
+		link_parsers:          Some(vec![
+			LinkParser {
+				pattern: Regex::new("#(\\d+)").unwrap(),
+				href:    String::from("https://github.com/$1"),
+				text:    None,
+			},
+			LinkParser {
+				pattern: Regex::new("https://github.com/(.*)").unwrap(),
+				href:    String::from("https://github.com/$1"),
+				text:    Some(String::from("$1")),
+			},
+		]),
 	};
 
 	let releases = vec![
 		Release {
 			version:   Some(String::from("v2.0.0")),
 			commits:   vec![
+				Commit::new(
+					String::from("000abc"),
+					String::from("Add unconventional commit"),
+				),
 				Commit::new(String::from("abc123"), String::from("feat: add xyz")),
 				Commit::new(String::from("abc124"), String::from("feat: add zyx")),
+				Commit::new(
+					String::from("abc124"),
+					String::from(
+						"feat(random-scope): add random feature\n\nThis is related to https://github.com/NixOS/nixpkgs/issues/136814\n\nCloses #123",
+					),
+				),
 				Commit::new(String::from("def789"), String::from("invalid commit")),
+				Commit::new(
+					String::from("def789"),
+					String::from("feat(big-feature)!: this is a breaking change"),
+				),
 				Commit::new(String::from("qwerty"), String::from("fix: fix abc")),
 				Commit::new(
 					String::from("qwop"),
@@ -68,14 +107,7 @@ fn generate_changelog() -> Result<()> {
 				),
 			]
 			.iter()
-			.filter_map(|c| {
-				c.process(
-					git_config.commit_parsers.as_ref(),
-					git_config.filter_commits,
-					git_config.conventional_commits,
-				)
-				.ok()
-			})
+			.filter_map(|c| c.process(&git_config).ok())
 			.collect::<Vec<Commit>>(),
 			commit_id: None,
 			timestamp: 0,
@@ -108,7 +140,7 @@ fn generate_changelog() -> Result<()> {
 	];
 
 	let out = &mut String::new();
-	let template = Template::new(changelog_config.body)?;
+	let template = Template::new(changelog_config.body.unwrap())?;
 
 	writeln!(out, "{}", changelog_config.header.unwrap()).unwrap();
 	for release in releases {
@@ -117,34 +149,33 @@ fn generate_changelog() -> Result<()> {
 	writeln!(out, "{}", changelog_config.footer.unwrap()).unwrap();
 
 	assert_eq!(
-		"this is a changelog
+		r#"this is a changelog
 
-        ## Release v2.0.0
-        
-        ### fix bugs
-        
-        - fix abc
-        
-        ### shiny features
-        
-        - add xyz
-        - add zyx
-        
-        ## Release v1.0.0
-        
-        ### chore
-        
-        - do nothing
-        
-        ### feat
-        
-        - add cool features
-        
-        ### fix
-        
-        - fix stuff
-        - fix more stuff
-        eoc - end of changelog\n",
+## Release v2.0.0
+
+### fix bugs
+- fix abc
+
+### shiny features
+- add xyz
+- add zyx
+- *(random-scope)* add random feature ([#123](https://github.com/123) [NixOS/nixpkgs/issues/136814](https://github.com/NixOS/nixpkgs/issues/136814) )
+- *(big-feature)* this is a breaking change
+  - **BREAKING**: this is a breaking change
+
+## Release v1.0.0
+
+### chore
+- do nothing
+
+### feat
+- add cool features
+
+### fix
+- fix stuff
+- fix more stuff
+eoc - end of changelog
+"#,
 		out
 	);
 
